#!/bin/sh
test -f tmp/description.rst && rm tmp/description.rst

gpg_key=tmp/key.gpg

cleanup() {
    test -f ${gpg_key} && rm ${gpg_key}
}
trap cleanup EXIT

# Script

# Exporte la clef privée
gpg --export-secret-keys --armor > ${gpg_key}

# Crée des lots distribués de manière équitable
size=$(wc -c tmp/key.gpg | cut -f 1 -d' ')
echo "Key size is $size"
# Crée des lots de 1260 octets max (pour tenir compte de la 
# redondance en cas d’erreur)
n=$((1+(size/1260))) 
split -n $n ${gpg_key} tmp/splitkey- 
rm ${gpg_key}

# Génère un QRCode pour chacun d'eux
for file in tmp/splitkey-??; do     
    qrencode --size 3 \
        --level H \
        -d 150 \
        -t eps -o "${file}.ps" \
        -r "${file}"
# Template

    cat >> tmp/description.rst << EOF

$(basename ${file}) - sha1 $(sha1sum ${file} | cut -f 1 -d' ')

.. image:: ${file}.ps
 :align: center
 :height: 12.2cm

EOF

done
